"""
Core functionality for interacting with the HNSearch API.
"""

import requests as req
import simplejson as json

from .date import Date
from . import thriftdb


class News(object):

    def __init__(self):
        self.url = "http://api.thriftdb.com/api.hnsearch.com/items/_search"

    def get(self, **params):
        """Perform a GET request."""
        params = thriftdb.convert(params)
        data = req.get(self.url, params=params)
        self.request = data
        return json.loads(data.content)

    def date(self, day):
        """Query a specific date."""
        day = Date(day)

    def hours(self, day, start, end):
        """Query a day by specific hours."""
        date = Date(day)
        start = date.hour(start)
        end = date.hour(end)

    def facet(self, term, **params):
        """Facets are almost like searching what can be searched."""
        params['facet'] = term
        return self.get(**params)

    def filter(self, condition, **params):
        """Filter the results to a specific condition."""
        params['filter'] = condition
        return self.get(**params)

    def search(self, term, **params):
        """Perform a search against the HNSearch API."""
        params['q'] = term
        return self.get(**params)



"""
Abstractions for dealing with dates. I don't know if you knew this, but dealing
with dates and times in Python kind of blows.
"""

import datetime
from collections import Iterable


class Date(object):

    def __init__(self, date):
        self._d = date

    def _convert_date(self):
        """Convert the given input to a date."""
        date = self._d
        if isinstance(date, str):
            # Check it's length -- YYYY-MM-DD vs MM-DD-YY
            print date
        elif isinstance(date, Iterable):
            # then it's an iterable
            print date
        else:
            # it's a datetime
            print date

    def hour(self, hour):
        """Add a time to the date."""
        if isinstance(hour, str):
            print hour
        else:
            print hour
        return self

    def __str__(self):
        return 'YYYY-MM-DD'

    def __repr__(self):
        return self.__str__()
